<?php

/**
 * proficia functions and definitions
  @package proficia
 *
*/

/* Set the content width in pixels, based on the theme's design and stylesheet.
*/
function proficia_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'proficia_content_width', 980 );
}
add_action( 'after_setup_theme', 'proficia_content_width', 0 );


if( ! function_exists( 'proficia_theme_setup' ) ) {	
	
	function proficia_theme_setup() {
		load_theme_textdomain( 'proficia', get_template_directory() . '/languages' );
		
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		
		// Add title tag 
		add_theme_support( 'title-tag' );
		
		// Add default logo support		
        add_theme_support( 'custom-logo');

        add_theme_support('post-thumbnails');
		add_image_size('proficia-about-thumbnail',555,370, true);
        add_image_size('proficia-client-img',130,130, true);
        add_image_size('proficia-blog-img',370,230, true);
        
        // Custom Backgrounds
		add_theme_support( 'custom-background', array(
			'default-color' => 'ffffff',
		) );
        
		
         // Add theme support for Semantic Markup
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) ); 

		$defaults = array(
			'default-image'          => get_template_directory_uri() .'/scripts/images/header.jpg',
			'width'                  => 1920,
			'height'                 => 600,
			'uploads'                => true,
			'default-text-color'     => "fff",
			'wp-head-callback'       => 'proficia_header_style',
		);
		add_theme_support( 'custom-header', $defaults );

		// Menus
		register_nav_menus(array(
			'primary' => esc_html__('Primary Menu', 'proficia'),
		));
		// add excerpt support for pages
        add_post_type_support( 'page', 'excerpt' );
		
        if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
        }
		// Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );
		

    	// To use additional css
 	    add_editor_style( 'scripts/css/editor-style.css' );
	}
	add_action( 'after_setup_theme', 'proficia_theme_setup' );
}

   // Register Nav Walker class_alias
    require get_template_directory(). '/class-wp-bootstrap-navwalker.php';
    require get_template_directory(). '/insert/extras.php';
   /**

    * Enqueue CSS stylesheets
    */		
if( ! function_exists( 'proficia_enqueue_styles' ) ) {
	function proficia_enqueue_styles() {	
	
	    wp_enqueue_style('proficia-font', 'https://fonts.googleapis.com/css?family=Montserrat:300,400,500,600,700|Open+Sans:300,400,600','');

		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/scripts/css/bootstrap.css','');
		wp_enqueue_style('font-awesome', get_template_directory_uri() .'/scripts/css/font-awesome.css','');
		
		wp_enqueue_style('jquery-owl-carousel', get_template_directory_uri() .'/scripts/css/owl.carousel.css','');
		wp_enqueue_style('owl-theme-default', get_template_directory_uri() .'/scripts/css/owl.theme.default.css','');
		wp_enqueue_style('meanmenu', get_template_directory_uri() .'/scripts/css/meanmenu.css','');
	
	// main style
		wp_enqueue_style( 'proficia-style', get_stylesheet_uri() );
		wp_enqueue_style('proficia-responsive', get_template_directory_uri() . '/scripts/css/responsive.css','');
	
	}
	add_action( 'wp_enqueue_scripts', 'proficia_enqueue_styles' );
}

/**
 * Enqueue JS scripts
 */

if( ! function_exists( 'proficia_enqueue_scripts' ) ) {
	function proficia_enqueue_scripts() {   
		//wp_enqueue_script('jquery');
		wp_enqueue_script('bootstrap', get_template_directory_uri() . '/scripts/js/bootstrap.js',array('jquery'),'', true);
		wp_enqueue_script('jquery-owl-carousel', get_template_directory_uri() . '/scripts/js/owl.carousel.js',array('jquery'),'', true);
		wp_enqueue_script('jquery-meanmenu', get_template_directory_uri() . '/scripts/js/jquery.meanmenu.js',array('jquery'),'', true);
		wp_enqueue_script('proficia-custom', get_template_directory_uri() . '/scripts/js/custom.js',array('jquery'),'', true);
		
	}
	add_action( 'wp_enqueue_scripts', 'proficia_enqueue_scripts' );
}


    function proficia_cat_count_span($links) {
        $links = str_replace('</a> (', '</a> <span>', $links);
        $links = str_replace(')', '</span>', $links);
        return $links;
    }
    add_filter('wp_list_categories', 'proficia_cat_count_span');


    function proficia_style_the_archive_count($links) {
        $links = str_replace('</a>&nbsp;(', '</a> <span class="archiveCount">', $links);
        $links = str_replace(')', '</span>', $links);
        return $links;
    }

    add_filter('get_archives_link', 'proficia_style_the_archive_count');


     /**
     * Register sidebars for proficia
     */

function proficia_sidebars() {

	// Blog Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "proficia"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "proficia"),
		'before_widget' => '<div id="%1$s" class="sidebar-wrap widget %2$s"><div class="sidebar-widget">',
		'after_widget' => '</div></div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	));
  	

	// Footer Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 1', "proficia"),
		'id' => 'proficia-footer-widget-area-1',
		'description' => esc_html__( 'The footer widget area 1', "proficia"),
		'before_widget' => ' <div class="footer-widgets %2$s">',
		'after_widget' => '</div> ',
		'before_title' => '<h3 class="foot-title">',
		'after_title' => '</h3>',
	));	
	

	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 2', "proficia"),
		'id' => 'proficia-footer-widget-area-2',
		'description' => esc_html__( 'The footer widget area 2', "proficia"),
		'before_widget' => '<div class="footer-widgets useful-links %2$s"> ',
		'after_widget' => ' </div>',
		'before_title' => '<h3 class="foot-title">',
		'after_title' => '</h3>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 3', "proficia"),
		'id' => 'proficia-footer-widget-area-3',
		'description' => esc_html__( 'The footer widget area 3', "proficia"),
		'before_widget' => '<div class="footer-widgets insta-feed %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="foot-title">',
		'after_title' => '</h3>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 4', "proficia"),
		'id' => 'proficia-footer-widget-area-4',
		'description' => esc_html__( 'The footer widget area 4', "proficia"),
		'before_widget' => '<div class="footer-widgets %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="foot-title">',
		'after_title' => '</h3>',
	));		
}

add_action( 'widgets_init', 'proficia_sidebars' );


/**
 * Styles the header text color displayed on the page header title
 *
 */

function proficia_header_style()
{
	$header_text_color = get_header_textcolor();
	?>
		<style type="text/css">
			 
				.site-title{
					color: #<?php echo esc_attr($header_text_color); ?>;
					
				}
			 
		</style>
	<?php

}

/**
 * Comment layout
 */
function proficia_comments( $comment, $args, $depth ) { ?>
	<div <?php comment_class('comments'); ?> id="<?php comment_ID() ?>">
		<?php if ($comment->comment_approved == '0') : ?>
			<div class="alert alert-info">
			  <p><?php esc_html_e( 'Your comment is awaiting moderation.', 'proficia' ) ?></p>
			</div>
		<?php endif; ?>
		<div class="commment">
                            <div class="blog-details-authoriamge">
                               <?php echo get_avatar( $comment,'88', null,'User', array( 'class' => array( 'media-object','' ) )); ?>                            </div>
                            <div class="comment__content">
                                <div class="comment__content__top">
                                    <h6>
                                        <?php 
                                            /* translators: '%1$s %2$s: edit term */
                                            printf(esc_html__( '%1$s %2$s', 'proficia' ), get_comment_author_link(), edit_comment_link(esc_html__( '(Edit)', 'proficia' ),'  ','') )
                                        ?>
                                            
                                        </h6>
                                    <span>
                                    	<time datetime="<?php echo comment_time('c'); ?>">
				                         <?php printf(  /* translators: 1: date, 2: time */
					                         _x( '%1$s at %2$s', '1: date, 2: time', 'proficia' ),
						                    get_comment_date(),
						                    get_comment_time()
					                    ); ?></time></span>
                                </div>
                                <?php comment_reply_link (array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
                                <div class="comment__content__bottom">
                                   <p><?php comment_text() ;?></p> 
                               </div>
                            </div>
                        </div>
		
	</div>
<?php
} 
 
/**
 * Customizer additions.
 */
  require get_template_directory(). '/insert/customizer.php';
  require get_template_directory(). '/insert/breadcrumbs.php';
  /**
 * Load theme about page
 */
require get_template_directory(). '/lib/about-theme/scholarship-about.php';
/**
 * Load Upsell Button In Customizer
 * 2016 &copy; [Justin Tadlock](http://justintadlock.com).
 */

require_once( trailingslashit( get_template_directory() ) . '/lib/upgrade/class-customize.php' );

add_action( 'admin_init', 'proficia_detect_button' );
	function proficia_detect_button() {
	wp_enqueue_style( 'proficia-info-button', get_template_directory_uri() . '/scripts/css/custom-button.css' );
} 
/**
 * admin  JS scripts
 */
function proficia_admin_enqueue_scripts( $hook ) { 
	wp_enqueue_style( 
		'font-awesome', 
		get_template_directory_uri() . '/scripts/css/font-awesome.css', 
		array(), 
		'4.7.0', 
		'all' 
	);
	wp_enqueue_style( 
		'proficia-admin', 
		get_template_directory_uri() . '/scripts/admin/css/admin.css', 
		array(), 
		'1.0.0', 
		'all' 
	);
 
}
add_action( 'admin_enqueue_scripts', 'proficia_admin_enqueue_scripts' );
?>