<?php
/**
 * proficia Theme Customizer
 *
 * @package proficia
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
*/


function proficia_customize_register( $wp_customize ) {  
     
    // proficia theme choice options
    if (!function_exists('proficia_section_choice_option')) :
        function proficia_section_choice_option()
        {
            $proficia_section_choice_option = array(
                'show' => esc_html__('Show', 'proficia'),
                'hide' => esc_html__('Hide', 'proficia')
            );
            return apply_filters('proficia_section_choice_option', $proficia_section_choice_option);
        }
    endif;
    
    /**
     * Sanitizing the select callback example
     *
     */
    if ( !function_exists('proficia_sanitize_select') ) :
        function proficia_sanitize_select( $input, $setting ) {

            // Ensure input is a slug.
            $input = sanitize_text_field( $input );

            // Get list of choices from the control associated with the setting.
            $choices = $setting->manager->get_control( $setting->id )->choices;

            // If the input is a valid key, return it; otherwise, return the default.
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }
    endif;

    /**
     * Drop-down Pages sanitization callback example.
     *
     * - Sanitization: dropdown-pages
     * - Control: dropdown-pages
     * 
     * Sanitization callback for 'dropdown-pages' type controls. This callback sanitizes `$page_id`
     * as an absolute integer, and then validates that $input is the ID of a published page.
     * 
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     * @see get_post_status() https://developer.wordpress.org/reference/functions/get_post_status/
     *
     * @param int                  $page    Page ID.
     * @param WP_Customize_Setting $setting Setting instance.
     * @return int|string Page ID if the page is published; otherwise, the setting default.
     */
    function proficia_sanitize_dropdown_pages( $page_id, $setting ) {
        // Ensure $input is an absolute integer.
        $page_id = absint( $page_id );
        
        // If $page_id is an ID of a published page, return it; otherwise, return the default.
        return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
    }
	
	/**
	 * Important Link
	*/
	 class proficia_theme_info_text extends WP_Customize_Control{
        public function render_content(){  ?>
            <span class="customize-control-title">
                <?php echo esc_html( $this->label ); ?>
            </span>
            <?php if($this->description){ ?>
                <span class="description customize-control-description">
                <?php echo wp_kses_post($this->description); ?>
                </span>
            <?php }
        }
    }
	 
	 
	$wp_customize->add_section( 'proficia_implink_section', array(
	  'title'       => esc_html__( 'Important Links', 'proficia' ),
	  'priority'      => 200
	) );

	    $wp_customize->add_setting( 'proficia_imp_links', array(
	      'sanitize_callback' => 'proficia_text_sanitize'
	    ));

	    $wp_customize->add_control( new proficia_theme_info_text( $wp_customize,'proficia_imp_links', array(
	        'settings'    => 'proficia_imp_links',
	        'section'   => 'proficia_implink_section',
	        'description' => '<a class="implink" href="http://themebarber.com/docs/proficia/index.html" target="_blank">'.esc_html__('Documentation', 'proficia').'</a><a class="implink" href="http://themebarber.com/product/proficia-demo/" target="_blank">'.esc_html__('Live Demo', 'proficia').'</a><a class="implink" href="https://wordpress.org/support/theme/proficia" target="_blank">'.esc_html__('Support Forum', 'proficia').'</a>',
	      )
	    ));

	    $wp_customize->add_setting( 'proficia_rate_us', array(
	      'sanitize_callback' => 'proficia_text_sanitize'
	    ));

	    $wp_customize->add_control( new proficia_theme_info_text( $wp_customize, 'proficia_rate_us', array(
	          'settings'    => 'proficia_rate_us',
	          'section'   => 'proficia_implink_section',
	          'description' => sprintf(__( 'Please do rate our theme if you liked it %1$s', 'proficia'), '<a class="implink" href="https://wordpress.org/support/theme/proficia/reviews/?filter=5" target="_blank">'.esc_html__('Rate/Review','proficia').'</a>' ),
	        )
	    ));

    
    
    /** Front Page Section Settings starts **/  

    $wp_customize->add_panel(
        'frontpage', 
        array(
            'title' => esc_html__('Proficia Options', 'proficia'),        
            'description' => '',                                        
            'priority' => 3,
        )
    );
    
/** Header Section Settings Start **/

    $wp_customize->add_section('proficia_header_info', 
        array(
            'title'       => esc_html__('Header Section', 'proficia'),
            'description' => '',
            'panel'       => 'frontpage',
            'priority'    => 40
        )
    );
  
    $wp_customize->add_setting(
    'proficia_header_section_hideshow',
    array(
        'default'           => 'hide',
        'sanitize_callback' => 'proficia_sanitize_select',
    )
    );

    $proficia_header_section_hide_show_option = proficia_section_choice_option();

    $wp_customize->add_control('proficia_header_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Header Option', 'proficia'),
            'description' => esc_html__('Show/hide option for Header Section.', 'proficia'),
            'section'     => 'proficia_header_info',
            'choices'     => $proficia_header_section_hide_show_option,
            'priority'    => 1
        )
    );
  

  
    $wp_customize->add_setting('proficia_header_phone_value', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('proficia_header_phone_value',
         array(
            'label'     => esc_html__('Contact', 'proficia'),
            'section'   => 'proficia_header_info',
            'priority'  => 3
        )
     );


    $wp_customize->add_setting('proficia_header_email_value', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('proficia_header_email_value',
        array(
            'label'    => esc_html__('Email', 'proficia'),
            'section'  => 'proficia_header_info',
            'priority' => 3
        )
    );

    $wp_customize->add_setting('proficia_header_social_link_1', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('proficia_header_social_link_1', 
        array(
            'label'   => esc_html__('Facebook URL', 'proficia'),
            'section' => 'proficia_header_info',
            'priority'  => 3
        )
    );

    $wp_customize->add_setting('proficia_header_social_link_2', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('proficia_header_social_link_2', 
        array(
            'label'   => esc_html__('Twitter URL', 'proficia'),
            'section' => 'proficia_header_info',
            'priority'  => 3
        )
    );

    $wp_customize->add_setting('proficia_header_social_link_3', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('proficia_header_social_link_3', 
        array(
            'label'   => esc_html__('Linkedin URL', 'proficia'),
            'section' => 'proficia_header_info',
            'priority'  => 3
        )
    );

    $wp_customize->add_setting('proficia_header_social_link_4', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('proficia_header_social_link_4', 
        array(
            'label'   => esc_html__('Youtube URL', 'proficia'),
            'section' => 'proficia_header_info',
            'priority'  => 3
        )
    );

    $wp_customize->add_setting('proficia_header_social_link_5', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('proficia_header_social_link_5', 
        array(
            'label'   => esc_html__('Instagram URL', 'proficia'),
            'section' => 'proficia_header_info',
            'priority'  => 3
        )
    );

 /** Header Section Settings end **/




    /** Slider Section Settings starts **/
   

    // Panel - Slider Section 1
    $wp_customize->add_section('proficia_sliderinfo', 
        array(
            'title'   => esc_html__('Home Slider Section', 'proficia'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 140
        )
    );

    // hide show
    
    $wp_customize->add_setting('proficia_slider_section_hideshow',
        array(
            'default' => 'hide',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );
     
    $proficia_section_choice_option = proficia_section_choice_option();
    
    $wp_customize->add_control(
    'proficia_slider_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Slider Option', 'proficia'),
            'description' => esc_html__('Show/hide option for Slider Section.', 'proficia'),
            'section' => 'proficia_sliderinfo',
            'choices' => $proficia_section_choice_option,
            'priority' => 1
        )
    );
  
    $proficia_slider_no = 3;
    for( $i = 1; $i <= $proficia_slider_no; $i++ ) {
        $proficia_slider_page = 'proficia_slider_page_' .$i;
        $proficia_slider_btntxt1 = 'proficia_slider_btntxt1_' . $i;
        $proficia_slider_btnurl1 = 'proficia_slider_btnurl1_' .$i;
        $proficia_slider_btntxt2 = 'proficia_slider_btntxt2_' . $i;
        $proficia_slider_btnurl2 = 'proficia_slider_btnurl2_' .$i;
         

        $wp_customize->add_setting( $proficia_slider_page,
            array(
                'default'           => 1,
                'sanitize_callback' => 'proficia_sanitize_dropdown_pages',
            )
        );

        $wp_customize->add_control( $proficia_slider_page,
            array(
                'label'             => esc_html__( 'Slider Page ', 'proficia' ) .$i,
                'section'           => 'proficia_sliderinfo',
                'type'              => 'dropdown-pages',
                'priority'          => 100,
            )
        );

        $wp_customize->add_setting( $proficia_slider_btntxt1,
            array(
                'default'           => '',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );

        $wp_customize->add_control( $proficia_slider_btntxt1,
            array(
                'label'             => esc_html__( 'Button Text 1','proficia' ),
                'section'           => 'proficia_sliderinfo',
                'type'              => 'text',
                'priority'          => 100,
            )
        );
        
        $wp_customize->add_setting( $proficia_slider_btnurl1,
            array(
                'default'           => '',
                'sanitize_callback' => 'esc_url_raw',
            )
        );

        $wp_customize->add_control( $proficia_slider_btnurl1,
            array(
                'label'             => esc_html__( 'Button URL 1', 'proficia' ),
                'section'           => 'proficia_sliderinfo',
                'priority'          => 100,
            )
        );

        $wp_customize->add_setting( $proficia_slider_btntxt2,
            array(
                'default'           => '',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );

        $wp_customize->add_control( $proficia_slider_btntxt2,
            array(
                'label'             => esc_html__( 'Button Text 2','proficia' ),
                'section'           => 'proficia_sliderinfo',
                'type'              => 'text',
                'priority'          => 100,
            )
        );
        
        $wp_customize->add_setting( $proficia_slider_btnurl2,
            array(
                'default'           => '',
                'sanitize_callback' => 'esc_url_raw',
            )
        );

        $wp_customize->add_control( $proficia_slider_btnurl2,
            array(
                'label'             => esc_html__( 'Button URL 2', 'proficia' ),
                'section'           => 'proficia_sliderinfo',
                'priority'          => 100,
            )
        );
    }
    /** Slider Section Settings end **/

    /** Features Section Settings Start **/

    $wp_customize->add_section('proficia_features',              
        array(
            'title'       => esc_html__('Features Section', 'proficia'),          
            'description' => '',             
            'panel'       => 'frontpage',      
            'priority'    => 140,
        )
    );
    
    $wp_customize->add_setting('proficia_features_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );

    $proficia_features_section_hide_show_option = proficia_section_choice_option();

    $wp_customize->add_control(
        'proficia_features_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Features Option', 'proficia'),
            'description' => esc_html__('Show/hide option for Features Section.', 'proficia'),
            'section'     => 'proficia_features',
            'choices'     => $proficia_features_section_hide_show_option,
            'priority'    => 1
        )
    );

   
    
   // features 
   
    $proficia_features_no = 3;
        for( $i = 1; $i <= $proficia_features_no; $i++ ) {
            $proficia_featurespage = 'proficia_features_page_' . $i;
            $proficia_featuresicon = 'proficia_page_features_icon_' . $i;
        
    // Setting - Feature Page
    
        
    $wp_customize->add_setting( $proficia_featurespage,
        array(
            'default'           => 1,
            'sanitize_callback' => 'proficia_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( $proficia_featurespage,
        array(
            'label'        => esc_html__( 'Features Page ', 'proficia' ) .$i,
            'section'      => 'proficia_features',
            'type'         => 'dropdown-pages',
            'priority'     => 100,
        )
    );

    $wp_customize->add_setting( 
            $proficia_featuresicon,
            array(
                'default'           => '',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );

        $wp_customize->add_control( 
            $proficia_featuresicon,
            array(
                'label'             => esc_html__( 'Features Icon ', 'proficia' ).$i,
                'description'       =>  __('Select a icon in this list <a target="_blank" href="https://fontawesome.com/v4.7.0/icons/">Font Awesome icons</a> and enter the class name','proficia'),
                'section'           => 'proficia_features',
                'type'              => 'text',
                'priority'          => 100,
            )
        );
    
    }
    /** Features Section Settings End **/

    //  Services section
    if (!function_exists('proficia_col_layout_option')) :
        function proficia_col_layout_option()
        {
            $proficia_col_layout_option = array(
                '6' => esc_html__('2 Column Layout', 'proficia'),
                '4' => esc_html__('3 Column Layout', 'proficia'),
                '3' => esc_html__('4 Column Layout', 'proficia'),
            );
            return apply_filters('proficia_col_layout_option', $proficia_col_layout_option);
        }
    endif;

    $wp_customize->add_section(
        'proficia_services',              
        array(
            'title' => esc_html__('Home Service Section', 'proficia'),          
            'description' => '',             
            'panel' => 'frontpage',      
            'priority' => 140,
        )
    );
    
    $wp_customize->add_setting(
        'proficia_services_section_hideshow',
        array(
            'default' => 'hide',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );
    
    $proficia_section_choice_option = proficia_section_choice_option();
    $wp_customize->add_control(
        'proficia_services_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Services Option', 'proficia'),
            'description' => esc_html__('Show/hide option Section.', 'proficia'),
            'section' => 'proficia_services',
            'choices' => $proficia_section_choice_option,
            'priority' => 1
        )
    );  

    // column layout
    $wp_customize->add_setting(
    'proficia_service_col_layout',
        array(
            'default' => '4',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );
    $proficia_section_col_layout = proficia_col_layout_option();
    
    $wp_customize->add_control(
    'proficia_service_col_layout',
        array(
            'type' => 'radio',
            'label' => esc_html__('Column Layout option ', 'proficia'),
            'description' => '',
            'section' => 'proficia_services',
            'choices' => $proficia_section_col_layout,
            'priority' => 2
        )
    );
   
   $wp_customize->add_setting(
        'proficia-services_title', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'proficia-services_title', 
        array(
            'label'   => esc_html__('Services Section Title', 'proficia'),
            'section' => 'proficia_services',
            'priority'  => 3
        )
    );

    $wp_customize->add_setting(
        'proficia-services_subtitle', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'proficia-services_subtitle',
        array(
            'label'   => esc_html__('Services Description', 'proficia'),
            'section' => 'proficia_services', 
            'priority'  => 4
        )
    );
    
    
    $proficia_service_no = 8;
    for( $i = 1; $i <= $proficia_service_no; $i++ ) {
        $proficia_servicepage = 'proficia_service_page_' . $i;
        $proficia_serviceicon = 'proficia_page_service_icon_' . $i;
        
        // Setting - Feature Icon
        $wp_customize->add_setting( 
            $proficia_serviceicon,
            array(
                'default'           => '',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );

        $wp_customize->add_control( 
            $proficia_serviceicon,
            array(
                'label'             => esc_html__( 'Service Icon ', 'proficia' ).$i,
                'description'       =>  __('Select a icon in this list <a target="_blank" href="https://fontawesome.com/v4.7.0/icons/">Font Awesome icons</a> and enter the class name','proficia'),
                'section'           => 'proficia_services',
                'type'              => 'text',
                'priority'          => 100,
            )
        );
        
        $wp_customize->add_setting( 
            $proficia_servicepage,
            array(
                'default'           => 1,
                'sanitize_callback' => 'proficia_sanitize_dropdown_pages',
            )
        );

        $wp_customize->add_control( 
            $proficia_servicepage,
            array(
                'label'             => esc_html__( 'Service Page ', 'proficia' ) .$i,
                'section'           => 'proficia_services',
                'type'              => 'dropdown-pages',
                'priority'          => 100,
            )
        );
    }
    
    
    // Blog section
    $wp_customize->add_section(
        'proficia-blog_info',
        array(
            'title'   => esc_html__('Home Blog Section', 'proficia'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 170
        )
    );
    
    $wp_customize->add_setting(
        'proficia_blog_section_hideshow',
        array(
            'default' => 'show',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );
    
    $proficia_section_choice_option = proficia_section_choice_option();
    $wp_customize->add_control(
        'proficia_blog_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Blog Option', 'proficia'),
            'description' => esc_html__('Show/hide option for Blog Section.', 'proficia'),
            'section' => 'proficia-blog_info',
            'choices' => $proficia_section_choice_option,
            'priority' => 1
        )
    );
    
    $wp_customize->add_setting(
        'proficia_blog_title',
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'proficia_blog_title',
        array(
            'label'   => esc_html__('Blog Title', 'proficia'),
            'section' => 'proficia-blog_info',
            'priority'  => 1
        )
    );

    $wp_customize->add_setting('proficia-blog_subtitle',
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('proficia-blog_subtitle', 
        array(
            'label'   => esc_html__('Blog Description', 'proficia'),
            'section' => 'proficia-blog_info', 
            'type'  => 'text',
            'priority'  => 2
        )
    );

    // Callout section
    $wp_customize->add_section(
        'proficia_footer_contact', 
        array(
            'title'   => esc_html__('Callout Section', 'proficia'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 150
        )
    );
    
    $wp_customize->add_setting(
        'proficia_contact_section_hideshow',
        array(
            'default' => 'hide',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );

    $proficia_section_choice_option = proficia_section_choice_option();
    $wp_customize->add_control(
        'proficia_contact_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Callout', 'proficia'),
            'description' => esc_html__('Show/hide option for Footer Callout Section.', 'proficia'),
            'section' => 'proficia_footer_contact',
            'choices' => $proficia_section_choice_option,
            'priority' => 5
        )
    );

    $wp_customize->add_setting(
        'ctah_heading', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'ctah_heading', 
        array(
            'label'   => esc_html__('Callout Title', 'proficia'),
            'section' => 'proficia_footer_contact',
            'priority'  => 8
        )
    );

    

    $wp_customize->add_setting(
        'ctah_btn_url', 
        array(
            'default'   =>'',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control(
        'ctah_btn_url', 
        array(
            'label'   => esc_html__('Button URL', 'proficia'),
            'section' => 'proficia_footer_contact',
            'priority'  => 11
        )
    );

    $wp_customize->add_setting(
        'ctah_btn_text', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'ctah_btn_text', 
        array(
            'label'   => esc_html__('Button Text', 'proficia'),
            'section' => 'proficia_footer_contact',
            'priority'  => 10
        )
    );
    
  

    // Footer Section
    
    $wp_customize->add_section(
        'proficia-footer_info',
        array(
            'title'   => esc_html__('Footer Section', 'proficia'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 170
        )
    );

    $wp_customize->add_setting(
        'proficia_footer_section_hideshow',
        array(
            'default' => 'show',
            'sanitize_callback' => 'proficia_sanitize_select',
        )
    );
    $proficia_section_choice_option = proficia_section_choice_option();
    $wp_customize->add_control(
        'proficia_footer_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Footer Option', 'proficia'),
            'description' => esc_html__('Show/hide option for Footer Section.', 'proficia'),
            'section' => 'proficia-footer_info',
            'choices' => $proficia_section_choice_option,
            'priority' => 1
        )
    );

    $wp_customize->add_setting(
        'proficia-footer_title',
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'wp_kses_post'
        )
    );

    $wp_customize->add_control(
        'proficia-footer_title',
        array(
            'label'   => esc_html__('Copyright', 'proficia'),
            'section' => 'proficia-footer_info',
            'type'      => 'textarea',
            'priority'  => 1
        )
    );
   
    
/** Front Page Section Settings end **/ 

}
add_action( 'customize_register', 'proficia_customize_register' );
